@@ -20,6 +20,15 @@
  * 
  */
 
+/** \example testprog1.c
+ *  \author Fernando Pujaico Rivera
+ *  \date 18-04-2011
+ *  \brief Programa para el testeo de las funciones de la biblioteca.
+ *  
+ *  Este programa solo hace una prueba simple de las funciones que hice
+ *  mas al tun tun.
+ */
+
 #include <config.h>
 #include <stdlib.h>
 #include <math.h>
@@ -48,13 +57,13 @@ int main(int argc, char* argv[])
 	}
 	fclose(fd);
 
-	pds_octplot_vector_in_png(Y,"Eje X","Eje Y",NULL,"vectory.png");
-	pds_octplot_vectors_in_png(NULL,Y,"Eje X","Eje Y",NULL,"vectorxy.png");
+	pds_octave_plot_vector(Y,"Eje X","Eje Y",NULL,"vectory.png");
+	pds_octave_plot_vectors(NULL,Y,"Eje X","Eje Y",NULL,"vectorxy.png");
 
-	pds_octplot_compare_vectors_in_png(NULL,X,Y,"n","f(n)","X","Y",NULL,"vector_xy.png");
+	pds_octave_plot_compare_vectors(NULL,X,Y,"n","f(n)","X","Y",NULL,"vector_xy.png");
 
-	pds_octplot_file_col_in_png("datos.dat",2,"n","Y[n]",NULL,"filecol2.png");
-	pds_octplot_file_cols_in_png("datos.dat",1,2,"X[n]","Y[n]",NULL,"filecol12.png");
+	pds_octave_plot_file_col("datos.dat",2,"n","Y[n]",NULL,"filecol2.png");
+	pds_octave_plot_file_cols("datos.dat",1,2,"X[n]","Y[n]",NULL,"filecol12.png");
 
 	pds_vector_free(X);
 	pds_vector_free(Y);
